Class: ERBLint::Linters::PartialPath::ConfigSchema

Inherits:
LinterConfig
  • Object
show all
Defined in:
lib/erb_lint/linters/partial_path_linter.rb

Overview

Configuration schema for the PartialPath linter.

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_prefixesArray<String>

Returns List of prefixes that are allowed to be used without full path.

Returns:

  • (Array<String>)

    List of prefixes that are allowed to be used without full path



26
27
28
# File 'lib/erb_lint/linters/partial_path_linter.rb', line 26

class ConfigSchema < LinterConfig
  property :allowed_prefixes, accepts: Array
end